################
# Ex2 solution #
################
data(sbs)
# 1) sbsdes: stratified, one-stage, unit sampling without replacement
sbsdes<-e.svydesign(data=sbs, ids=~id, strata=~strata, weights=~weight, fpc=~fpc)
sbsdes


# 2) Calibration constraints:
#    (i)  counts of enterprises by area
#    (ii) total of emp.num by nace.macro
#
#    One possible calmodel specification:
#    - calmodel = ~area + emp.num:nace.macro - 1

#    A second alternative (using variable 'ent', which is always equal to 1,
#    to count enterprises):
#    - calmodel = ~ent:area + emp.num:nace.macro - 1


# 3) Build the template:
sbspop<-pop.template(data=sbsdes, calmodel=~area + emp.num:nace.macro - 1)


# 4) Check that it is ok:
sbspop
pop.desc(sbspop)


# 5) Let ReGenesees compute the needed known totals from the sampling frame and
#    and automatically fill the template:
sbspop<-fill.template(universe=sbs.frame, template=sbspop)
sbspop


# 6) Calibrate sbsdes following the stated requirements:
#    First, get suggested bounds for range-restricted calibration:
bounds.h<-bounds.hint(design=sbsdes, df.population=sbspop)

#    Then, execute the calibration task:
sbscal<-e.calibrate(sbsdes, sbspop, calfun="logit", bounds=bounds.h, sigma2=~emp.num)


# 7) Check for calibration convergence:
check.cal(sbscal)


# 8) Compute the range of the obtained g-weights:
g.range(sbscal)

#    Thus, it was not necessary to use all the range allowed by the suggested
#    bounds, notably at the lower endpoint:
bounds.h


# 9) For the fast attendees:
# - maxit = 2
ko.cal.2<-e.calibrate(sbsdes, sbspop, calfun="logit", bounds=bounds.h, sigma2=~emp.num, maxit=2)
# - maxit = 3
ko.cal.3<-e.calibrate(sbsdes, sbspop, calfun="logit", bounds=bounds.h, sigma2=~emp.num, maxit=3)
# - maxit = 4
ko.cal.4<-e.calibrate(sbsdes, sbspop, calfun="logit", bounds=bounds.h, sigma2=~emp.num, maxit=4)

# 10) Discrepancies from calibration benchmarks:
check.cal(ko.cal.2)
check.cal(ko.cal.3)
check.cal(ko.cal.4)

#     Whereas maxit = 5 achieves convergence:
check.cal(e.calibrate(sbsdes, sbspop, calfun="logit", bounds=bounds.h, sigma2=~emp.num, maxit=5))
