################
# Ex4 solution #
################
# Import samp.csv. May use the GUI of ReGenesees or the command line (change the
# path to the file if needed)
samp <- read.table(file="samp.csv", header=TRUE, sep=";", na.strings=NA, quote="\"", dec=".", strip.white=TRUE, comment.char="")

# 1) des1: stratified 2-stage, with PSUs and SSUs selected WITHOUT replacement
des1 <- e.svydesign(data=samp, ids=~psu+ssu, strata=~stratum, weights=~w, fpc=~fpc1+fpc2)
des1

# 2) des2: stratified 1-stage, with PSUs selected WITHOUT replacement
des2 <- e.svydesign(data=samp, ids=~psu, strata=~stratum, weights=~w, fpc=~fpc1)
des2

# 3) des3: stratified 1-stage, with PSUs selected WITH replacement (thus, must
#          NOT pass fpc1)
des3 <- e.svydesign(data=samp, ids=~psu, strata=~stratum, weights=~w)
des3

# 4) des4:
des4 <- e.svydesign(data=samp, ids=~psu+ssu, strata=~stratum, weights=~w, fpc=~fpc1)
des4

# Answer: For des4, ReGenesees will treat the SSUs as if they have been
#         'censused' (i.e. sampled with sampling rate 1) within each sampled PSU.


################
# Ex5 solution #
################
# 1) des1: 2-stage PSUs WOR SSUs WOR
Y.1 <- svystatTM(des1, ~y)
Y.1

# 2) des2: 1-stage PSUs WOR
Y.2 <- svystatTM(des2, ~y)
Y.2

# 3) des3: 1-stage PSUs WR
Y.3 <- svystatTM(des3, ~y)
Y.3

# 4) des4: 2-stage PSUs WOR SSUs Censused
Y.4 <- svystatTM(des4, ~y)
Y.4

# Answer 1: Estimated totals Y.1, ..., Y.4 are identical because POINT estimates
#           ONLY depend on y values and survey weights w, and both are the same
#           in all 4 designs.
#           If data and weights are the same, different sampling designs passed
#           to ReGenesees can only affect estimates of the sampling VARIANCE,
#           which are indeed different, as discussed below.

# Observed SE hierarchy:
# SE.2 = SE.4 < SE.1 < SE.3
stopifnot( SE(Y.2) == SE(Y.4), SE(Y.4) < SE(Y.1), SE(Y.1) < SE(Y.3) )

# Answer 2.1: des4 is only nominally 2-stage, since SSUs are censused.
#             Actually, it is a 1-stage cluster sample of PSUs selected WOR,
#             therefore identical to des2.

# Answer 2.2: des4 and des2 have smaller SE than des1, as des1 is identical to
#             them at first stage, but involves a second stage of sampling,
#             which adds further sampling variability.

# Answer 2.2: des3 has the highest SE as it is theoretically known that the
#             1-stage WITH replacement approximation of any multistage design
#             WITHOUT replacement ALWAYS OVERESTIMATES the actual multistage
#             sampling variance.
