################
# Ex3 solution #
################
# Import small.csv. May use the GUI of ReGenesees or the command line (change
# the path to the file if needed)
small <- read.table(file="small.csv", header=TRUE, sep=";", na.strings=NA, quote="\"", dec=".", strip.white=TRUE, comment.char="")

# Define a suitable design object
smalldes <- e.svydesign(data=small, ids=~ towcod+famcod, strata=~ stratum, weights=~ d, fpc=~ Ntow+Nfam)

# Add to smalldes new variable 'ones' identically equal to 1
smalldes <- des.addvars(smalldes, ones=1)

# Add to smalldes  new variable famdensity = 1/famsize
smalldes <- des.addvars(smalldes, famdensity = 1/famsize)

# Compute the requested estimates
# 1) Nhh: Total number of households
Nhh <- svystatTM(smalldes, y=~famdensity)
Nhh

# 2) Nind: Total number of individuals
Nind <- svystatTM(smalldes, y=~ones)
Nind

# 3) Avg.famsize: Average family size (i.e. average number of individuals per household)
Avg.famsize <- svystatR(smalldes, num=~ones, den=~famdensity)
Avg.famsize
# And indeed
coef(Avg.famsize)
coef(Nind)/coef(Nhh)

# 4) Nhh.by.famsize: Counts of households by household size
Nhh.by.famsize <- svystatTM(smalldes, y=~famdensity, by=~famsize)
Nhh.by.famsize


# Calibrate simultaneously on totals referred to the population of individuals
# and on the population of households

# Calibration totals:
#  (i) Total number of individuals by sex.
Nind.sex <- c("f" = 112, "m" = 98)

# (ii) Total number of households by region.
Nhh.region <- c("Center" = 37, "North" = 65, "South" = 45)

# Build and fill the template
pop <- pop.template(smalldes, calmode=~sex+ famdensity:region-1)
pop[,] <- c(Nind.sex, Nhh.region)

# Calibrate with Linear unbounded distance
smallcal <- e.calibrate(smalldes, pop)

# Compute the calibration estimate of average family size
Avg.famsizeCAL <- svystatR(smallcal, num=~ones, den=~famdensity)
# Compare CAL and HT
Avg.famsizeCAL
Avg.famsize

# The SE of Avg.famsizeCAL is zero because the exploited known totals imply that
# the total amounts of both individuals and households is exactly known. Thus,
# their ratio is also known without uncertainty.
